==> prototools-0.1.29.tar.gz: prototools-0.1.29/README.md <==
# `prototools`

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](./code_of_conduct.md)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/prototools/badge/?version=latest)](https://prototools.readthedocs.io/es/latest/?badge=latest)
![maintenance](https://img.shields.io/maintenance/yes/2022)

                       __       __            __  
        ___  _______  / /____  / /____  ___  / /__
       / _ \/ __/ _ \/ __/ _ \/ __/ _ \/ _ \/ (_-<
      / .__/_/  \___/\__/\___/\__/\___/\___/_/___/
     /_/ 


`prototools` is a set of tools that considerably reduce the amount of time 
spent writing console applications. 


# Installation

`prototools` is available on [PyPi](https://pypi.org/project/prototools/) (MIT license) 
and installation can be performed by running [pip](https://docs.python.org/es/3/installing/index.html)

```
python -m pip install prototools
```
To upgrade the package:
```
python -m pip install prototools --upgrade
```
> 📝 It's recommended to use virtual environment.

To delete the package:
```
python -m pip uninstall prototools
```


# Documentation

You can read the documentation at [here](https://proto-tools.github.io/docs/)


# Contribution

You can contribute with ``prototools`` in so many ways (not just coding).
Every idea is welcome! You can suggest new features or report a bug when
you find it. Every contribution that you made it'll be mention in this 
project.

==> prototools-0.1.32.7.tar.gz: prototools-0.1.32.7/README.md <==
# `prototools`

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](./code_of_conduct.md)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://readthedocs.org/projects/prototools/badge/?version=latest)](https://prototools.readthedocs.io/es/latest/?badge=latest)
![maintenance](https://img.shields.io/maintenance/yes/2024)

                       __       __            __
        ___  _______  / /____  / /____  ___  / /__
       / _ \/ __/ _ \/ __/ _ \/ __/ _ \/ _ \/ (_-<
      / .__/_/  \___/\__/\___/\__/\___/\___/_/___/
     /_/

`prototools` is a set of tools that considerably reduce the amount of time
spent writing console applications.

# Installation

`prototools` is available on [PyPi](https://pypi.org/project/prototools/) (MIT license)
and installation can be performed by running [pip](https://docs.python.org/es/3/installing/index.html)

```
python -m pip install prototools
```

To upgrade the package:

```
python -m pip install prototools --upgrade
```

> 📝 It's recommended to use virtual environment.

To delete the package:

```
python -m pip uninstall prototools
```

# Documentation

You can read the documentation at [here](https://proto-tools.github.io/docs/)

# Contribution

You can contribute with `prototools` in so many ways (not just coding).
Every idea is welcome! You can suggest new features or report a bug when
you find it. Every contribution that you made it'll be mention in this
project.
